==> collective.js.galleria-1.6.1.tar.gz: collective.js.galleria-1.6.1/src/collective/js/galleria/tests/test_setup.py <==
# -*- coding: utf-8 -*-
from collective.js.galleria.testing import INTEGRATION_TESTING
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.registry.interfaces import IRegistry
from Products.CMFPlone.interfaces import IBundleRegistry
from Products.CMFPlone.utils import get_installer
from zope.component import getUtility

import unittest


PROJECTNAME = "collective.js.galleria"
JS = "++resource++collective.galleria.min.js"


class InstallTestCase(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        self.registry = getUtility(IRegistry)
        self.qi_tool = get_installer(self.portal, self.request)

    def test_installed(self):
        self.assertTrue(
            self.qi_tool.isProductInstalled(PROJECTNAME),
            "package appears not to have been installed",
        )

    def test_jsregistry(self):
        bundles = self.registry.collectionOfInterface(
            IBundleRegistry, prefix="plone.bundles"
        )
        bundle = bundles["galleria.js"]

        self.assertEqual(bundle.jscompilation, JS)


class UninstallTestCase(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        self.registry = getUtility(IRegistry)
        self.qi_tool = get_installer(self.portal, self.request)
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        self.qi_tool.uninstallProducts(products=[PROJECTNAME])

    def test_uninstalled(self):
        self.assertFalse(self.qi_tool.isProductInstalled(PROJECTNAME))

    def test_jsregistry_removed(self):
        bundles = self.registry.collectionOfInterface(
            IBundleRegistry, prefix="plone.bundles"
        )

        self.assertNotIn("galleria.js", bundles.keys())

==> collective.js.galleria-1.6.2.tar.gz: collective.js.galleria-1.6.2/src/collective/js/galleria/tests/test_setup.py <==
# -*- coding: utf-8 -*-
from collective.js.galleria.testing import INTEGRATION_TESTING
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.registry.interfaces import IRegistry
from Products.CMFPlone.controlpanel.browser.quickinstaller import ManageProductsView
from Products.CMFPlone.interfaces import IBundleRegistry
from Products.CMFPlone.utils import get_installer
from zope.component import getUtility

import unittest


PROJECTNAME = "collective.js.galleria"
JS = "++plone++collective.js.galleria/galleria.min.js"


class InstallTestCase(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        self.registry = getUtility(IRegistry)
        self.instaler = get_installer(self.portal, self.request)

    def test_installed(self):
        self.assertTrue(
            self.instaler.isProductInstalled(PROJECTNAME),
            "package appears not to have been installed",
        )

    def test_jsregistry(self):
        bundles = self.registry.collectionOfInterface(
            IBundleRegistry, prefix="plone.bundles"
        )
        bundle = bundles["galleria.js"]

        self.assertEqual(bundle.jscompilation, JS)

    def test_hide_upgrades_profiles(self):
        mp = ManageProductsView(self.portal, self.request)
        profiles = mp.get_available()
        package_profiles_availables = [
            profile["id"]
            for profile in profiles
            if profile["id"].startswith("collective.js.galleria")
        ]
        self.assertEqual([], package_profiles_availables)


class UninstallTestCase(unittest.TestCase):

    layer = INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        self.registry = getUtility(IRegistry)
        self.instaler = get_installer(self.portal, self.request)
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        self.instaler.uninstallProducts(products=[PROJECTNAME])

    def test_uninstalled(self):
        self.assertFalse(self.instaler.isProductInstalled(PROJECTNAME))

    def test_jsregistry_removed(self):
        bundles = self.registry.collectionOfInterface(
            IBundleRegistry, prefix="plone.bundles"
        )

        self.assertNotIn("galleria.js", bundles.keys())
